@@ -41,13 +41,13 @@ def do_config_host_list(sc, args):
         ]
 
         formatters = {
-            'host_name': lambda x: x['host_name'],
-            'address': lambda x: x['address'],
+            'host_name': lambda x: x.get('host_name', ''),
+            'address': lambda x: x.get('address', '')
         }
         utils.print_list(hosts, cols, formatters=formatters)
 
 
-@cliutils.arg("host_name", help="Name of the host")
+@cliutils.arg("--host_name", help="Name of the host")
 @cliutils.arg("--address", help="Address of the host")
 @cliutils.arg("--max_check_attempts")
 @cliutils.arg("--check_period")
@@ -70,6 +70,8 @@ def do_config_host_update(sc, args):
                  'use']
     host = _dict_from_args(args, arg_names)
 
+    host["host_name"] = args.host_name
+
     if "custom_fields" in host:
         host["custom_fields"] = json.loads(host["custom_fields"])
 
@@ -106,7 +108,7 @@ def do_config_host_create(sc, args):
     sc.config.hosts.create(**host)
 
 
-@cliutils.arg("host_name", help="Name of the host")
+@cliutils.arg("--host_name", help="Name of the host")
 def do_config_host_show(sc, args):
     """Show a specific host."""
     host = sc.config.hosts.get(args.host_name)
@@ -124,7 +126,7 @@ def do_config_host_show(sc, args):
         utils.print_item(host, hostProperties)
 
 
-@cliutils.arg("host_name", help="Name of the host")
+@cliutils.arg("--host_name", help="Name of the host")
 def do_config_host_delete(sc, args):
     """Create a config host."""
     sc.config.hosts.delete(args.host_name)
@@ -145,10 +147,10 @@ def do_config_service_list(sc, args):
         ]
 
         formatters = {
-            'service_description': lambda x: x['service_description'],
-            'host_name': lambda x: x['host_name'],
-            'check_period': lambda x: x['check_period'],
-            'contact_groups': lambda x: x['contact_groups'],
+            'service_description': lambda x: x.get('service_description', ''),
+            'host_name': lambda x: x.get('host_name', ''),
+            'check_period': lambda x: x.get('check_period', ''),
+            'contact_groups': lambda x: x.get('contact_groups', ''),
         }
         utils.print_list(services, cols, formatters=formatters)
 
@@ -164,6 +166,7 @@ def do_config_service_list(sc, args):
 @cliutils.arg("--notification_period")
 @cliutils.arg("--contacts")
 @cliutils.arg("--contact_groups")
+@cliutils.arg("--passive_checks_enabled")
 def do_config_service_create(sc, args):
     """Create a config service."""
     arg_names = ['host_name',
@@ -177,13 +180,14 @@ def do_config_service_create(sc, args):
                  'notification_period',
                  'contacts',
                  'contact_groups',
+                 'passive_checks_enabled',
                  'use']
     service = _dict_from_args(args, arg_names)
     sc.config.services.create(**service)
 
 
-@cliutils.arg("host_name", help="Name of the host")
-@cliutils.arg("service_description", help="The service_description")
+@cliutils.arg("--host_name", help="Name of the host")
+@cliutils.arg("--service_description", help="The service_description")
 def do_config_service_delete(sc, args):
     """Create a config host."""
     sc.config.services.delete(args.host_name,
@@ -204,9 +208,10 @@ def do_config_checkmodulation_list(sc, args):
         ]
 
         formatters = {
-            'check_command': lambda x: x['check_command'],
-            'check_period': lambda x: x['check_period'],
-            'checkmodulation_name': lambda x: x['checkmodulation_name']
+            'check_command': lambda x: x.get('check_command', ''),
+            'check_period': lambda x: x.get('check_period', ''),
+            'checkmodulation_name': lambda x: x.get('checkmodulation_name',
+                                                    ''),
         }
         utils.print_list(checkmodulations, cols, formatters=formatters)
 
@@ -242,8 +247,8 @@ def do_config_command_list(sc, args):
         ]
 
         formatters = {
-            'command_name': lambda x: x['command_name'],
-            'command_line': lambda x: x['command_line']
+            'command_name': lambda x: x.get('command_name', ''),
+            'command_line': lambda x: x.get('command_line', ''),
         }
         utils.print_list(commands, cols, formatters=formatters)
 
@@ -321,7 +326,7 @@ def do_status_host_list(sc, args):
         utils.print_list(services, cols, formatters=formatters)
 
 
-@cliutils.arg("host_name", help="The host_name")
+@cliutils.arg("--host_name", help="The host_name")
 def do_status_host_show(sc, args):
     host = sc.status.hosts.get(args.host_name)
 
@@ -361,10 +366,10 @@ def do_status_service_list(sc, args):
         utils.print_list(services, cols, formatters=formatters)
 
 
-@cliutils.arg("host_name", help="Name of the host")
-@cliutils.arg("metric_name", help="Name of the metric")
-@cliutils.arg("time_begin", help="begin of the metric")
-@cliutils.arg("time_end", help="end of the metric")
+@cliutils.arg("--host_name", help="Name of the host")
+@cliutils.arg("--metric_name", help="Name of the metric")
+@cliutils.arg("--time_begin", help="begin of the metric")
+@cliutils.arg("--time_end", help="end of the metric")
 @cliutils.arg("--service_description", help="Service description")
 def do_status_metrics_list(sc, args):
     """List all status metrics."""
@@ -399,8 +404,8 @@ def do_status_metrics_list(sc, args):
         utils.print_list(metrics, cols, formatters=formatters)
 
 
-@cliutils.arg("host_name", help="Name of the host")
-@cliutils.arg("metric_name", help="Name of the metric")
+@cliutils.arg("--host_name", help="Name of the host")
+@cliutils.arg("--metric_name", help="Name of the metric")
 @cliutils.arg("--service_description", help="Service description")
 def do_status_metrics_show(sc, args):
     """Give the last status metrics."""
@@ -425,7 +430,28 @@ def do_status_metrics_show(sc, args):
         utils.print_item(metric, metricProperties)
 
 
-@cliutils.arg("host_name", help="Name of the host")
+@cliutils.arg("--host_name", help="Name of the host")
+@cliutils.arg("--service_description", help="Service description")
+@cliutils.arg("--output", help="The output of the plugin")
+@cliutils.arg("--return_code", help="The return code of the plugin")
+def do_status_submit_check_result(sc, args):
+    """Submit a check result."""
+    if args.service_description:
+        sc.status.services.submit_check_result(
+            args.host_name,
+            args.service_description,
+            output=args.output,
+            return_code=int(args.return_code),
+        )
+    else:
+        sc.status.hosts.submit_check_result(
+            args.host_name,
+            output=args.output,
+            return_code=int(args.return_code),
+        )
+
+
+@cliutils.arg("--host_name", help="Name of the host")
 @cliutils.arg("--service_description", help="Service description")
 @cliutils.arg("--time_stamp")
 def do_action_recheck(sc, args):
